@@ -101,6 +101,10 @@ static const QString AboutText = QString::fromUtf8(
     "<LI><B>Guillaume Moulard</B> - Log4PL/SQL documentation.\n"
     "<LI><B>ZippyDufus@yahoo.com</B> - Win32 cross compile build documentation.\n"
     "</UL>\n"
+    "Financial and Project Support (In alphabetical order):<P>\n"
+    "<UL>\n"
+    "<LI><B>Eric Johnson</B>\n"
+    "</UL>\n"
     "Other contributors:<P>\n"
     "<B>Nuno Araujo</B>,\n"
     "<B>Ivan Brezina</B>,\n"
