@@ -2,39 +2,39 @@
 /* BEGIN_COMMON_COPYRIGHT_HEADER
  *
  * TOra - An Oracle Toolkit for DBA's and developers
- * 
+ *
  * Shared/mixed copyright is held throughout files in this product
- * 
+ *
  * Portions Copyright (C) 2000-2001 Underscore AB
  * Portions Copyright (C) 2003-2005 Quest Software, Inc.
  * Portions Copyright (C) 2004-2009 Numerous Other Contributors
- * 
+ *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
  * as published by the Free Software Foundation;  only version 2 of
  * the License is valid for this program.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
- * 
+ *
  *      As a special exception, you have permission to link this program
  *      with the Oracle Client libraries and distribute executables, as long
  *      as you follow the requirements of the GNU GPL in regard to all of the
  *      software in the executable aside from Oracle client libraries.
- * 
+ *
  *      Specifically you are not permitted to link this program with the
  *      Qt/UNIX, Qt/Windows or Qt Non Commercial products of TrollTech.
  *      And you are not permitted to distribute binaries compiled against
- *      these libraries. 
- * 
+ *      these libraries.
+ *
  *      You may link this product with any GPL'd Qt library.
- * 
+ *
  * All trademarks belong to their respective owners.
  *
  * END_COMMON_COPYRIGHT_HEADER */
@@ -57,8 +57,8 @@ class QGridLayout;
 class QLineEdit;
 
 class toBrowserTable : public QDialog,
-            public Ui::toBrowserTableUI,
-            public toConnectionWidget
+        public Ui::toBrowserTableUI,
+        public toConnectionWidget
 {
 
 private:
@@ -77,9 +77,16 @@ private:
 
     int ColumnNumber;
 
+    // lists pointers to all widgets containing column data
     std::list<QLineEdit *> ColumnNames;
     std::list<toDatatype *> Datatypes;
-    std::list<QLineEdit *> Extra;
+    std::list<QCheckBox *> NotNulls;
+    std::list<QLineEdit *> Defaults;
+    std::list<QLineEdit *> Comments;
+//    std::list<QLineEdit *> Extra; // not sure if this still needed as it was
+    // split into NotNull and DefaultValue
+    bool tablespaceSpecified; // indicates if original description of table
+    // has tablespace specified in description
 
     toBrowserTable(toConnection &conn,
                    const QString &owner,
@@ -96,6 +103,9 @@ private:
 protected:
     virtual void resizeEvent(QResizeEvent *e);
 
+public slots:
+    virtual void done(int r);
+
 public:
     static void editTable(toConnection &conn,
                           const QString &owner,
@@ -116,6 +126,7 @@ public slots:
 
 private:
     bool UglyFlag;
+    toConnection * cnct;
 
 private slots:
     virtual void uglyWorkaround();
