@@ -2,39 +2,39 @@
 /* BEGIN_COMMON_COPYRIGHT_HEADER
  *
  * TOra - An Oracle Toolkit for DBA's and developers
- * 
+ *
  * Shared/mixed copyright is held throughout files in this product
- * 
+ *
  * Portions Copyright (C) 2000-2001 Underscore AB
  * Portions Copyright (C) 2003-2005 Quest Software, Inc.
  * Portions Copyright (C) 2004-2009 Numerous Other Contributors
- * 
+ *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
  * as published by the Free Software Foundation;  only version 2 of
  * the License is valid for this program.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
- * 
+ *
  *      As a special exception, you have permission to link this program
  *      with the Oracle Client libraries and distribute executables, as long
  *      as you follow the requirements of the GNU GPL in regard to all of the
  *      software in the executable aside from Oracle client libraries.
- * 
+ *
  *      Specifically you are not permitted to link this program with the
  *      Qt/UNIX, Qt/Windows or Qt Non Commercial products of TrollTech.
  *      And you are not permitted to distribute binaries compiled against
- *      these libraries. 
- * 
+ *      these libraries.
+ *
  *      You may link this product with any GPL'd Qt library.
- * 
+ *
  * All trademarks belong to their respective owners.
  *
  * END_COMMON_COPYRIGHT_HEADER */
@@ -51,6 +51,7 @@
 #include <qspinbox.h>
 #include <QHBoxLayout>
 
+static QString noValue = QString("-"); // this value indicates that size is NOT specified (use db default)
 
 toDatatype::toDatatype(toConnection &conn,
                        const QString &def,
@@ -74,7 +75,7 @@ toDatatype::toDatatype(toConnection &conn,
         setObjectName(name);
 
     setup(conn);
-    setType("VARCHAR(32)");
+    setType("VARCHAR2(32)");
 }
 
 void toDatatype::setup(toConnection &conn)
@@ -101,6 +102,8 @@ void toDatatype::setup(toConnection &conn)
 
     Size = new QSpinBox(this);
     Size->setMinimum(0);
+    Size->setSpecialValueText(noValue); // size can be NOT specified (use db default)
+    bSizeVisible = true;
     hbox->addWidget(Size);
 
     Comma = new QLabel(tr("<B>,</B>"), this);
@@ -110,6 +113,8 @@ void toDatatype::setup(toConnection &conn)
 
     Precision = new QSpinBox(this);
     Precision->setMinimum(0);
+    Precision->setSpecialValueText(noValue); // precision can be NOT specified (use db default)
+    bPrecVisible = true;
     hbox->addWidget(Precision);
 
     RightParenthesis = new QLabel(tr("<B>)</B>"), this);
@@ -125,13 +130,17 @@ void toDatatype::setup(toConnection &conn)
     connect(Type, SIGNAL(activated(int)), this, SLOT(changeType(int)));
 
     setLayout(hbox);
+
+    bCustomVisible = false;
+    bSizeVisible = true;
+    bPrecVisible = true;
 }
 
 
 QString toDatatype::type() const
 {
     QString type;
-    if (Custom->isVisible())
+    if (bCustomVisible)
     {
         type = Custom->text();
     }
@@ -139,13 +148,13 @@ QString toDatatype::type() const
     {
         type = Type->currentText();
         bool par = false;
-        if (Size->isVisible())
+        if (bSizeVisible && (Size->text() != noValue))
         {
             type += "(";
             par = true;
             type += Size->text();
         }
-        if (Precision->isVisible())
+        if (bPrecVisible && (Precision->text() != noValue))
         {
             if (!par)
             {
@@ -162,6 +171,9 @@ QString toDatatype::type() const
     return type;
 }
 
+// Function tries to split given datatype (type) into a number of
+// ui widgets (type, scale and precision). If it is unable to do
+// that - custom style (pure edit text widget) is used
 void toDatatype::setType(const QString &type)
 {
     try
@@ -183,7 +195,7 @@ void toDatatype::setType(const QString &type)
         bool endoftoken = false;
         if (valid)
         {
-            for (int pos = 0;pos < type.length();pos++)
+            for (int pos = 0; pos < type.length(); pos++)
             {
                 QChar c = type.at(pos);
                 if (c.isSpace())
@@ -270,11 +282,12 @@ void toDatatype::setType(const QString &type)
             {
                 QString actualtype = type.mid(startType, endType - startType + 1).toUpper();
                 valid = false;
-                for (int i = 0;i < Type->count();i++)
+                for (int i = 0; i < Type->count(); i++)
                 {
                     if (actualtype == Type->itemText(i))
                     {
                         Type->show();
+                        bCustomVisible = false;
                         Type->setCurrentIndex(i);
                         valid = true;
                         break;
@@ -283,7 +296,7 @@ void toDatatype::setType(const QString &type)
                 if (valid)
                 {
                     valid = false;
-                    for (std::list<toExtract::datatype>::iterator i = Datatypes.begin();i != Datatypes.end();i++)
+                    for (std::list<toExtract::datatype>::iterator i = Datatypes.begin(); i != Datatypes.end(); i++)
                     {
                         if ((*i).name() == actualtype)
                         {
@@ -295,17 +308,22 @@ void toDatatype::setType(const QString &type)
                                 else
                                 {
                                     Size->show();
+                                    bSizeVisible = true;
                                     Size->setMaximum((*i).maxLength());
                                     if (size != -1)
                                         Size->setValue(size);
                                     else
-                                        Size->setValue((*i).maxLength());
+                                        //Size->setValue((*i).maxLength());
+                                        Size->setValue(0); // set value "not specified"
                                 }
                             }
                             else if (size != -1)
                                 valid = false;
                             else
+                            {
                                 Size->hide();
+                                bSizeVisible = false;
+                            }
                             if ((*i).hasPrecision())
                             {
                                 if (precision > (*i).maxPrecision())
@@ -313,17 +331,25 @@ void toDatatype::setType(const QString &type)
                                 else
                                 {
                                     Precision->show();
+                                    bPrecVisible = true;
                                     Precision->setMaximum((*i).maxPrecision());
                                     if (precision != -1)
                                         Precision->setValue(precision);
                                     else
-                                        Precision->setValue((*i).maxPrecision());
+                                        // Set precision to 0 (meaning "precision not specified").
+                                        // If precision 0 can actually be used -1 should be used
+                                        // here and minimum value on precision spinner should be
+                                        // changed to -1 so that spinner would allow choosing 0
+                                        Precision->setValue(0);
                                 }
                             }
                             else if (precision != -1)
                                 valid = false;
                             else
+                            {
                                 Precision->hide();
+                                bPrecVisible = false;
+                            }
                             break;
                         }
                     }
@@ -334,12 +360,18 @@ void toDatatype::setType(const QString &type)
         {
             Custom->setText(type);
             Custom->show();
+            bCustomVisible = true;
             Precision->hide();
+            bPrecVisible = false;
             Size->hide();
+            bSizeVisible = false;
             Type->hide();
         }
         else
+        {
             Custom->hide();
+            bCustomVisible = false; // probably set already above but just for clarity...
+        }
 
         setupLabels();
     }
@@ -363,24 +395,32 @@ void toDatatype::setCustom(bool prefer)
 void toDatatype::changeType(int id)
 {
     QString type = Type->itemText(id);
-    for (std::list<toExtract::datatype>::iterator i = Datatypes.begin();i != Datatypes.end();i++)
+    for (std::list<toExtract::datatype>::iterator i = Datatypes.begin(); i != Datatypes.end(); i++)
     {
         if ((*i).name() == type)
         {
             if ((*i).hasLength())
             {
-                Size->setShown(true);
+                Size->show();
+                bSizeVisible = true;
                 Size->setMaximum((*i).maxLength());
             }
             else
-                Size->setShown(false);
+            {
+                Size->hide();
+                bSizeVisible = false;
+            }
             if ((*i).hasPrecision())
             {
-                Precision->setShown(true);
+                Precision->show();
+                bPrecVisible = true;
                 Precision->setMaximum((*i).maxPrecision());
             }
             else
-                Precision->setShown(false);
+            {
+                Precision->hide();
+                bPrecVisible = false;
+            }
             break;
         }
     }
