@@ -608,6 +608,7 @@ static const char *DefaultKeywords[] =
     "ROLES",
     "ROLLBACK",
     "ROLLUP",
+    "ROW",
     "ROWDEPENDENCIES",
     "ROWID",
     "ROWNUM",
@@ -756,6 +757,7 @@ static const char *DefaultKeywords[] =
     "UROWID",
     "USAGE",
     "USE",
+    "USER",
     "USER_DEFINED",
     "USE_PRIVATE_OUTLINES",
     "USE_STORED_OUTLINES",
