@@ -55,6 +55,7 @@
 #include <qtimer.h>
 #include <qkeysequence.h>
 #include <Qsci/qsciapis.h>
+#include <Qsci/qsciabstractapis.h>
 #include <qnamespace.h>
 #include <QListWidget>
 #include <QtDebug>
@@ -363,8 +364,8 @@ toHighlightedText::toHighlightedText(QWidget *parent, const char *name)
     sqlLexer()->setFoldComments(true);
     sqlLexer()->setFoldCompact(false);
 
-    // enable syntax colouring
-    setSyntaxColoring (true);
+    // enable syntax colouring if "Syntax highlighting" is on in editor preferences
+    setSyntaxColoring(toConfigurationSingle::Instance().highlight());
 
     // set the font
     setFont(toStringToFont(toConfigurationSingle::Instance().codeFont()));
@@ -375,7 +376,8 @@ toHighlightedText::toHighlightedText(QWidget *parent, const char *name)
     m_debugMarginHandle = markerDefine(QsciScintilla::Rectangle);
     m_debugHandle = markerDefine(QsciScintilla::Background);
 
-    m_currentLineMarginHandle = markerDefine(QsciScintilla::RightArrow);
+// FIXME: disabled due repainting issues
+//    m_currentLineMarginHandle = markerDefine(QsciScintilla::RightArrow);
 
     m_bookmarkMarginHandle = markerDefine(QsciScintilla::RightTriangle);
     m_bookmarkHandle = markerDefine(QsciScintilla::Background);
@@ -478,9 +480,10 @@ void toHighlightedText::positionChanged(int row, int col)
         if (timer->isActive())
             timer->stop();
     }
+// FIXME: disabled due repainting issues
     // current line marker (margin arrow)
-    markerDeleteAll(m_currentLineMarginHandle);
-    markerAdd(row, m_currentLineMarginHandle);
+//    markerDeleteAll(m_currentLineMarginHandle);
+//    markerAdd(row, m_currentLineMarginHandle);
 }
 
 static QString UpperIdent(const QString &str)
@@ -961,7 +964,7 @@ QStringList toHighlightedText::getCompletionList(QString* partial)
     {
         QString cmp = UpperIdent(name);
         QString lastToken;
-        while ((invalidToken(tokens.line(), tokens.offset() + token.length()) || UpperIdent(token) != cmp || lastToken == ".") && token != ";" && !token.isEmpty())
+        while ((invalidToken(tokens.line(), tokens.offset() + token.length()) || UpperIdent(token) != cmp || lastToken == ".") && token != ";" && token != "~~~" && !token.isEmpty())
         {
             lastToken = token;
             token = tokens.getToken(false);
@@ -1000,19 +1003,33 @@ QStringList toHighlightedText::getCompletionList(QString* partial)
         try
         {
             toConnection &conn = toCurrentConnection(this);
-            toQDescList &desc = conn.columns(conn.realName(name, false));
-            for (toQDescList::iterator i = desc.begin(); i != desc.end(); i++)
+            toConnection::objectName object = conn.realName(name, false);
+            if(object.Type == "DATABASE")
             {
-                QString t;
-                int ind = (*i).Name.indexOf("(");
-                if (ind < 0)
-                    ind = (*i).Name.indexOf("RETURNING") - 1; //it could be a function or procedure without parameters. -1 to remove the space
-                if (ind >= 0)
-                    t = conn.quote((*i).Name.mid(0, ind)) + (*i).Name.mid(ind);
-                else
-                    t = conn.quote((*i).Name);
-                if (t.indexOf(*partial) == 0)
-                    toReturn.append(t);
+                std::list<toConnection::objectName> list = conn.tables(object);
+                Q_FOREACH(toConnection::objectName table, list)
+                {
+                    QString t = conn.quote(table.Name, false);
+                    if(t.indexOf(*partial) == 0)
+                        toReturn.append(t);
+                }
+            }
+            else
+            {
+                toQDescList &desc = conn.columns(object);
+                for (toQDescList::iterator i = desc.begin(); i != desc.end(); i++)
+                {
+                    QString t;
+                    int ind = (*i).Name.indexOf("(");
+                    if (ind < 0)
+                        ind = (*i).Name.indexOf("RETURNING") - 1; //it could be a function or procedure without parameters. -1 to remove the space
+                    if (ind >= 0)
+                        t = conn.quote((*i).Name.mid(0, ind), false) + (*i).Name.mid(ind);
+                    else
+                        t = conn.quote((*i).Name, false);
+                    if (t.indexOf(*partial) == 0)
+                        toReturn.append(t);
+                }
             }
         }
         catch (QString e)
