@@ -223,6 +223,12 @@ toModelEditor::toModelEditor(QWidget *parent,
     connect(WordWrapAct, SIGNAL(toggled(bool)),
              Editor, SLOT(setWordWrap(bool)));
              Toolbar->addAction(WordWrapAct);
+             
+    QAction * XMLWrapAct = new QAction(QIcon(":/icons/xmlwrap.png"), tr("XML Format"), Toolbar);
+    XMLWrapAct->setCheckable(true);
+    connect(XMLWrapAct, SIGNAL(toggled(bool)),
+             Editor, SLOT(setXMLWrap(bool)));
+    Toolbar->addAction(XMLWrapAct);
 
     if (Editable)
     {
@@ -326,10 +332,20 @@ void toModelEditor::store()
 void toModelEditor::changePosition(QModelIndex index)
 {
     Current = index;
+    QVariant const &data = Model->data(Current, Qt::UserRole);
+    if(data.type() == QVariant::UserType)
+    {
+           toQValue::complexType *i = data.value<toQValue::complexType*>();
+           setText(i->summary());
+           return;
+    }
+           
     if(Editable)
-        setText(Model->data(Current, Qt::EditRole).toString());
+           setText(Model->data(Current, Qt::EditRole).toString());
     else
-        setText(Model->data(Current, Qt::DisplayRole).toString());
+    {
+           setText(Model->data(Current, Qt::DisplayRole).toString());
+    }
 }
 
 void toModelEditor::firstColumn()
