@@ -83,6 +83,17 @@ static toSQL SQLCommentPG(
     "7.1",
     "PostgreSQL");
 
+static toSQL SQLCommentTD(
+    "toResultCols:Comments",
+    "SELECT c.columnname,\n"
+    "       c.commentstring\n"
+    "  FROM dbc.COLUMNS c\n"
+    " WHERE trim ( databasename ) = trim ( :f1<char[100]> )\n"
+    "   AND trim ( tablename ) = trim ( :f2<char[100]> )",
+    "",
+    "",
+    "Teradata");
+
 static toSQL SQLTableCommentMySQL(
     "toResultCols:TableComment",
     "SHOW TABLE STATUS FROM `:f1<noquote>` LIKE :f2<char[100]>",
@@ -90,6 +101,17 @@ static toSQL SQLTableCommentMySQL(
     "4.1",
     "MySQL");
 
+
+static toSQL SQLTableCommentTD(
+    "toResultCols:TableComment",
+    "SELECT c.commentstring\n"
+    "  FROM dbc.tables c\n"
+    " WHERE trim ( databasename ) = trim ( :f1<char[100]> )\n"
+    "   AND trim ( tablename ) = trim ( :f2<char[100]> )",
+    "",
+    "",
+    "Teradata");
+
 static toSQL SQLTableComment(
     "toResultCols:TableComment",
     "SELECT Comments FROM sys.All_Tab_Comments\n"
@@ -367,13 +389,36 @@ static toSQL SQLTableColumnsPG(
     "7.1",
     "PostgreSQL");
 
-static toSQL SQLTableColumnsMySql(
+static toSQL SQLTableColumnsTD(
+    "toResultCols:ListCols",
+    "SELECT c.columnname AS \"Name\",\n"
+    "       c.columntitle AS \"Title\",\n"
+    "       c.columntype AS \"Type\",\n"
+    "       c.defaultvalue AS \"Default Value\",\n"
+    "       c.nullable AS \"Null\",\n"
+    "       c.createtimestamp AS \"Created\",\n"
+    "       c.lastaltertimestamp AS \"Last Modified\",\n"
+    "       c.CommentString AS \"Comment\"\n"
+    "  FROM dbc.COLUMNS c\n"
+    " WHERE trim ( databasename ) = trim ( :f1<char[100]> )\n"
+    "   AND trim ( tablename ) = trim ( :f2<char[100]> )\n"
+    " ORDER BY 1",
+    "",
+    "",
+    "Teradata");
+
+static toSQL SQLTableColumnsMySql3(
     "toResultCols:ListCols",
     "SHOW FULL COLUMNS FROM :f1<noquote>",
     "",
     "3.23",
     "MySQL");
-
+static toSQL SQLTableColumnsMySql(
+    "toResultCols:ListCols",
+    "SELECT * FROM information_schema.columns WHERE table_schema = :f1<char[101]> AND table_name = :f2<char[101]>",
+    "",
+    "5.0",
+    "MySQL");
 
 toResultCols::toResultCols(QWidget *parent, const char *name, Qt::WFlags f)
         : QWidget(parent, f)
@@ -485,17 +530,18 @@ void toResultCols::query(const QString &sql, const toQList &param)
         TableName = conn.quote(Owner) + "." + conn.quote(Name);
 
         Columns->setSQL(SQLTableColumns);
-        if (toIsMySQL(conn))
-        {
-            if (Owner.isEmpty())
-                Columns->changeParams(Name);
-            else
-                Columns->changeParams("`" + Owner + "`." + Name);
-        }
-        else
-        {
+        // MySQL is using information_schema now - so there should be always Owner defined
+//         if (toIsMySQL(conn))
+//         {
+//             if (Owner.isEmpty())
+//                 Columns->changeParams(Name);
+//             else
+//                 Columns->changeParams("`" + Owner + "`." + Name);
+//         }
+//         else
+//         {
             Columns->changeParams(Owner, Name);
-        }
+//         }
     }
     TOCATCH;
 
@@ -551,8 +597,9 @@ void toResultCols::query(const QString &sql, const toQList &param)
         label += QString::fromLatin1("</B>");
 
         if (connection().provider() == "Oracle" ||
-                connection().provider() == "MySQL" ||
-                connection().provider() == "PostgreSQL")
+            connection().provider() == "MySQL" ||
+            connection().provider() == "PostgreSQL" ||
+            connection().provider() == "Teradata")
         {
             toConnection &conn = connection();
             toQuery query(conn, SQLTableComment, Owner, Name);
