@@ -50,7 +50,7 @@
 
 
 toResultCombo::toResultCombo(QWidget *parent, const char *name)
-        : QComboBox(parent), Query(0)
+  : QComboBox(parent), Query(0), SelectionPolicy(None)
 {
     setObjectName(name);
     connect(&Poll, SIGNAL(timeout()), this, SLOT(poll()));
@@ -93,27 +93,53 @@ void toResultCombo::poll(void)
     {
         if (!toCheckModal(this))
             return ;
+
         if (Query && Query->poll())
         {
-            while (Query->poll() && !Query->eof())
-            {
-                QString t = Query->readValue();
-                addItem(t);
-                if (t == Selected)
-                    setCurrentIndex(count() - 1);
-            }
+		while (Query->poll() && !Query->eof())
+		{
+    			QString t = Query->readValue();
+    			QStringList l;
+        		for(unsigned i=1; i<Query->describe().size(); ++i)
+        		{
+        			QString v = Query->readValue();
+        			l.append(v);
+        		}
+    			addItem(t, QVariant(l));
+    			if (t == Selected)
+    				setCurrentIndex(count() - 1);
+		}
 
             if (Query->eof())
             {
-                Poll.stop();
-                setFont(font()); // Small hack to invalidate size hint of combobox which should resize to needed size.
-                updateGeometry();
+		    Poll.stop();
+		    switch(SelectionPolicy)
+		    {
+		    case First:
+			    if (currentIndex() != 0)
+				    setCurrentIndex(0);
+			    break;
+		    case Last:
+			    if (currentIndex() != count()-1)
+				    setCurrentIndex(count()-1);
+			    break;
+		    case LastButOne:
+			    if (currentIndex() != count()-2)
+				    setCurrentIndex(count()-2);
+			    break;
+		    case None:
+			    ;
+		    };
+		    setFont(font()); // Small hack to invalidate size hint of combobox which should resize to needed size.
+		    updateGeometry();
+		    emit done();
             }
         }
     }
     catch (const QString &exc)
     {
         Poll.stop();
+        emit done();
         toStatusMessage(exc);
     }
 }
