@@ -7,7 +7,7 @@
  * 
  * Portions Copyright (C) 2000-2001 Underscore AB
  * Portions Copyright (C) 2003-2005 Quest Software, Inc.
- * Portions Copyright (C) 2004-2008 Numerous Other Contributors
+ * Portions Copyright (C) 2004-2009 Numerous Other Contributors
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -66,6 +66,33 @@ toResultPlan::toResultPlan(QWidget *parent, const char *name)
     oracleSetup();
 }
 
+static toSQL SQLViewVSQLPlan("toResultPlan:ViewVSQLPlan",
+                         "SELECT ID,NVL(Parent_ID,0),Operation, Options, Object_Name, Optimizer,cost,\n"
+                         "  io_cost,Bytes,Cardinality,\n"
+                         "  partition_start,partition_stop,temp_space,time\n"
+                         "FROM V$SQL_PLAN WHERE Address||':'||Hash_Value = '%1' and child_number = 0"
+			 "ORDER BY NVL(Parent_ID,0),ID",
+                         "Get the contents of SQL plan from V$SQL_PLAN.",
+                         "1000");
+
+static toSQL SQLViewVSQLPlan92("toResultPlan:ViewVSQLPlan",
+                         "SELECT ID,NVL(Parent_ID,0),Operation, Options, Object_Name, Optimizer,cost,\n"
+                         "  io_cost,Bytes,Cardinality,\n"
+                         "  partition_start,partition_stop,temp_space,null time\n"
+                         "FROM V$SQL_PLAN WHERE Address||':'||Hash_Value = '%1' and child_number = 0"
+			 "ORDER BY NVL(Parent_ID,0),ID",
+                         "",
+                         "0902");
+
+static toSQL SQLViewVSQLPlan9("toResultPlan:ViewVSQLPlan",
+                         "SELECT ID,NVL(Parent_ID,0),Operation, Options, Object_Name, Optimizer,cost,\n"
+                         "  io_cost,Bytes,Cardinality,\n"
+                         "  partition_start,partition_stop,null temp_space,null time\n"
+                         "FROM V$SQL_PLAN WHERE Address||':'||Hash_Value = '%1' and child_number = 0"
+			 "ORDER BY NVL(Parent_ID,0),ID",
+                         "",
+                         "0900");
+
 static toSQL SQLViewPlan("toResultPlan:ViewPlan",
                          "SELECT ID,NVL(Parent_ID,0),Operation, Options, Object_Name, Optimizer,cost,\n"
                          "  io_cost,Bytes,Cardinality,\n"
@@ -148,29 +175,36 @@ void toResultPlan::oracleNext(void)
         sql = sql.mid(0, sql.length() - 1);
 
     QString explain = QString::fromLatin1("EXPLAIN PLAN SET STATEMENT_ID = '%1' INTO %2.%3 FOR %4").
-                      arg(Ident).arg(connection().user()).arg(planTable).arg(toSQLStripSpecifier(sql));
+                      arg(Ident).arg(conn.user()).arg(planTable).arg(toSQLStripSpecifier(sql));
+	
     if (!User.isNull() && User != conn.user().toUpper())
     {
         try
         {
-            conn.execute(QString::fromLatin1("ALTER SESSION SET CURRENT_SCHEMA = %1").arg(User));
+            conn.execute(QString::fromLatin1("ALTER SESSION SET CURRENT_SCHEMA = \"%1\"").arg(User));
             conn.execute(explain);
         }
         catch (...)
         {
             try
             {
-                conn.execute(QString::fromLatin1("ALTER SESSION SET CURRENT_SCHEMA = %1").arg(connection().user()));
+                // conn.execute(QString::fromLatin1("ALTER SESSION SET CURRENT_SCHEMA = %1").arg(connection().user()));
+		// when we start connection it is for user but in schema context
+                conn.execute(QString::fromLatin1("ALTER SESSION SET CURRENT_SCHEMA = \"%1\"").arg(connection().schema()));
             }
             catch (...)
                 {}
             throw;
         }
-        conn.execute(QString::fromLatin1("ALTER SESSION SET CURRENT_SCHEMA = %1").arg(connection().user()));
+        //conn.execute(QString::fromLatin1("ALTER SESSION SET CURRENT_SCHEMA = %1").arg(connection().user()));
+	//when we start connection it is for user but in schema context
+        conn.execute(QString::fromLatin1("ALTER SESSION SET CURRENT_SCHEMA = \"%1\"").arg(connection().schema()));
         toQList par;
         Query = new toNoBlockQuery(connection(), toQuery::Normal,
-                                   toSQL::string(SQLViewPlan, connection()).
-                                   arg(toConfigurationSingle::Instance().planTable()).
+                                   toSQL::string(SQLViewPlan, conn).
+				   // arg(toConfigurationSingle::Instance().planTable()).
+				   // Since EXPLAIN PLAN is always to conn.user() plan_table
+				   arg(conn.user()+QString(".")+toConfigurationSingle::Instance().planTable()).
                                    arg(Ident), par);
         Reading = true;
     }
@@ -180,7 +214,7 @@ void toResultPlan::oracleNext(void)
         toQList par;
         Query = new toNoBlockQuery(conn, toQuery::Normal, explain, par);
     }
-    TopItem = new toResultViewItem(this, TopItem, QString::fromLatin1("DML"));
+    TopItem = new toResultViewItem(this, TopItem, QString::fromLatin1("EXPLAIN PLAN:"));
     TopItem->setText(1, sql.left(50).trimmed());
     Poll.start(100);
 }
@@ -287,8 +321,25 @@ void toResultPlan::query(const QString &sql,
             Last.clear();
             TopItem = new toResultViewItem(this, NULL, QString::fromLatin1("DML"));
             TopItem->setText(1, QString::fromLatin1("Saved plan"));
+	    Poll.start(100);
         }
-        else
+        else if (sql.startsWith(QString::fromLatin1("SGA:")))
+        {
+            QString Address = sql.mid(4);
+	    toConnection &conn = connection();
+            toQList par;
+            Query = new toNoBlockQuery(conn, toQuery::Background,
+                                       toSQL::string(SQLViewVSQLPlan, conn).arg(Address),
+                                       par);
+            Reading = true;
+	    LastTop = NULL;
+            Parents.clear();
+            Last.clear();
+            TopItem = new toResultViewItem(this, NULL, QString::fromLatin1("V$SQL_PLAN:"));
+            TopItem->setText(1, toSQLString(conn, Address).left(50).trimmed());
+	    Poll.start(100);
+        }
+	else
         {
             TopItem = NULL;
             std::list<toSQLParse::statement> ret = toSQLParse::parse(sql);
@@ -315,9 +366,13 @@ void toResultPlan::poll(void)
                 toQList par;
                 delete Query;
                 Query = NULL;
+		toConnection &conn = connection();
                 Query = new toNoBlockQuery(connection(), toQuery::Normal,
-                                           toSQL::string(SQLViewPlan, connection()).
-                                           arg(toConfigurationSingle::Instance().planTable()).
+                                           toSQL::string(SQLViewPlan, conn).
+                                           // arg(toConfigurationSingle::Instance().planTable()).
+					   // Since EXPLAIN PLAN is always to conn.user() plan_table
+					   // and current_schema can be different
+					   arg(conn.user()+QString(".")+toConfigurationSingle::Instance().planTable()).
                                            arg(Ident), par);
                 Reading = true;
             }
