@@ -2,39 +2,39 @@
 /* BEGIN_COMMON_COPYRIGHT_HEADER
  *
  * TOra - An Oracle Toolkit for DBA's and developers
- * 
+ *
  * Shared/mixed copyright is held throughout files in this product
- * 
+ *
  * Portions Copyright (C) 2000-2001 Underscore AB
  * Portions Copyright (C) 2003-2005 Quest Software, Inc.
  * Portions Copyright (C) 2004-2008 Numerous Other Contributors
- * 
+ *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
  * as published by the Free Software Foundation;  only version 2 of
  * the License is valid for this program.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
- * 
+ *
  *      As a special exception, you have permission to link this program
  *      with the Oracle Client libraries and distribute executables, as long
  *      as you follow the requirements of the GNU GPL in regard to all of the
  *      software in the executable aside from Oracle client libraries.
- * 
+ *
  *      Specifically you are not permitted to link this program with the
  *      Qt/UNIX, Qt/Windows or Qt Non Commercial products of TrollTech.
  *      And you are not permitted to distribute binaries compiled against
- *      these libraries. 
- * 
+ *      these libraries.
+ *
  *      You may link this product with any GPL'd Qt library.
- * 
+ *
  * All trademarks belong to their respective owners.
  *
  * END_COMMON_COPYRIGHT_HEADER */
@@ -55,6 +55,28 @@
 #include <QPaintEvent>
 #include <QProgressDialog>
 
+
+// columns count
+#define FILECOLUMNS 15
+#define COLUMNS (FILECOLUMNS-2)
+// order of the result columns
+#define COL_NAME 0
+#define COL_STATUS 1
+#define COL_INFO 2
+#define COL_CONTENT 3
+#define COL_LOGGING 4
+#define COL_SIZE 5
+#define COL_FREE_UNIT 6
+#define COL_FREE_PERCENT 7
+#define COL_AUTOEXT 8
+#define COL_USED_FREE_AUTO 9
+#define COL_COALESCED 10
+#define COL_MAX_FREE 11
+#define COL_FREE_FRAGMENTS 12
+
+
+/*! \brief Item for storage data display and sorting.
+*/
 class toResultStorageItem : public toResultViewItem
 {
     bool AvailableGraph;
@@ -67,6 +89,60 @@ public:
                         const QString &buf = QString::null)
             : toResultViewItem(parent, after, buf), AvailableGraph(available)
     { }
+
+	//! Try to guess real type of the value taken from DB
+    void setSortValue(int col, const QVariant & v)
+    {
+    	bool ok;
+    	int i = v.toInt(&ok);
+    	if (ok)
+   		{
+   			m_sortValues[col] = i;
+   			return;
+   		}
+   		double d = v.toDouble(&ok);
+   		if (ok)
+   		{
+   			m_sortValues[col] = d;
+   			return;
+   		}
+   		m_sortValues[col] = v;
+   	}
+
+	//! See operator<
+    QVariant sortValue(int i) const
+    {
+    	return m_sortValues[i];
+   	}
+
+	/*! Operator used for sorting. Original operator handles
+	    only string-based sorting. Now it supports int and double
+	    for numeric columns.
+	 */
+    bool operator<(const QTreeWidgetItem &other) const
+    {
+        int column = treeWidget()->sortColumn();
+        QVariant v(m_sortValues[column]);
+
+        const toResultStorageItem * o = dynamic_cast<const toResultStorageItem*>(&other);
+        Q_ASSERT_X(o, "cast", "only toResultStorageItem are supported");
+
+        switch (v.type())
+        {
+        	case QVariant::Int:
+	        	return v.toInt() < o->sortValue(column).toInt();
+        	case QVariant::Double:
+				return v.toDouble() < o->sortValue(column).toDouble();
+        	case QVariant::String:
+	        	return v.toString() < o->sortValue(column).toString();
+	        default:
+	        	Q_ASSERT_X(0, "compare", "more comparation is not supported now");
+	    };
+    }
+
+private:
+	//! Store the value used for sorting for every column
+	QHash<int,QVariant> m_sortValues;
 };
 
 class toResultStorageItemDelegate: public QItemDelegate
@@ -76,18 +152,18 @@ public:
     {
     }
 
-    void paint(QPainter *painter, const QStyleOptionViewItem &option, 
-               const QModelIndex & index ) const  
+    void paint(QPainter *painter, const QStyleOptionViewItem &option,
+               const QModelIndex & index ) const
     {
-        if(index.column() == 8 ) {
+        if(index.column() == COL_USED_FREE_AUTO ) {
             int left   = option.rect.left();
             int top    = option.rect.top();
             int width  = option.rect.width();
             int height = option.rect.height();
-   
+
             QString str = index.model()->data(index, Qt::DisplayRole).toString();
             QStringList pct = str.split(QRegExp("/"));
-            
+
             if (pct.count() == 3) {
                 int w_used = (int) (pct.at(0).toDouble() * width / 100);
                 int w_free = (int) (pct.at(1).toDouble() * width / 100);
@@ -129,6 +205,7 @@ toResultStorage::toResultStorage(bool available, QWidget *parent, const char *na
     addColumn(tr("Logging"));
     addColumn(tr("Size (%1)").arg(Unit));
     addColumn(tr("Free (%1)").arg(Unit));
+    addColumn(tr("Free (%)"));
     addColumn(tr("Autoextend (%1)").arg(Unit));
     if (available)
         addColumn(tr("Used/Free/Autoextend"));
@@ -139,13 +216,14 @@ toResultStorage::toResultStorage(bool available, QWidget *parent, const char *na
     addColumn(tr("Free fragments"));
     setSQLName(tr("toResultStorage"));
 
-    setColumnAlignment(5, Qt::AlignRight);
-    setColumnAlignment(6, Qt::AlignRight);
-    setColumnAlignment(7, Qt::AlignRight);
-    setColumnAlignment(8, Qt::AlignCenter);
-    setColumnAlignment(9, Qt::AlignCenter);
-    setColumnAlignment(10, Qt::AlignRight);
-    setColumnAlignment(11, Qt::AlignRight);
+    setColumnAlignment(COL_SIZE, Qt::AlignRight);
+    setColumnAlignment(COL_FREE_UNIT, Qt::AlignRight);
+    setColumnAlignment(COL_FREE_PERCENT, Qt::AlignRight);
+    setColumnAlignment(COL_AUTOEXT, Qt::AlignCenter);
+    setColumnAlignment(COL_USED_FREE_AUTO, Qt::AlignCenter);
+    setColumnAlignment(COL_COALESCED, Qt::AlignRight);
+    setColumnAlignment(COL_MAX_FREE, Qt::AlignRight);
+    setColumnAlignment(COL_FREE_FRAGMENTS, Qt::AlignRight);
 
     ShowCoalesced = false;
     OnlyFiles = false;
@@ -170,6 +248,7 @@ static toSQL SQLShowCoalesced("toResultStorage:ShowCoalesced",
                               "       d.logging,\n"
                               "       TO_CHAR(ROUND(NVL(a.tbs_size,0) / b.unit,2)),\n"
                               "       TO_CHAR(ROUND(NVL(f.free_size,0) / b.unit,2)),\n"
+                              "       TO_CHAR(ROUND(NVL(f.free_size,0)/NVL(a.tbs_size,1)*100)),\n" // free%
                               "       TO_CHAR(ROUND(NVL(a.autoextend_size,0) / b.unit,2)),\n"
                               "       '-',\n"
                               "       TO_CHAR(ROUND(f.percent_extents_coalesced,1))||'%',\n"
@@ -198,6 +277,7 @@ static toSQL SQLShowCoalesced("toResultStorage:ShowCoalesced",
                               "       d.logging,\n"
                               "       TO_CHAR(ROUND(NVL(a.tbs_size,0) / b.unit,2)),\n"
                               "       TO_CHAR(ROUND(NVL(f.free_size,0) / b.unit,2)),\n"
+                              "       TO_CHAR(ROUND(NVL(f.free_size,0)/NVL(a.tbs_size,1)*100)),\n" // free%
                               "       TO_CHAR(ROUND(NVL(a.autoextend_size,0) / b.unit,2)),\n"
                               "       '-',\n"
                               "       '-',\n"
@@ -231,6 +311,7 @@ static toSQL SQLShowCoalesced8("toResultStorage:ShowCoalesced",
                                "       d.logging,\n"
                                "       TO_CHAR(ROUND(NVL(a.bytes / b.unit, 0),2)),\n"
                                "       TO_CHAR(ROUND(NVL(f.bytes,0) / b.unit,2)),\n"
+                               "       TO_CHAR(ROUND(NVL(f.bytes,0)/NVL(a.bytes,1)*100)),\n" // free%
                                "       TO_CHAR(ROUND(NVL(a.maxbytes / b.unit, 0),2)),\n"
                                "       '-',\n"
                                "       TO_CHAR(ROUND(f.percent_extents_coalesced,1))||'%',\n"
@@ -254,6 +335,7 @@ static toSQL SQLShowCoalesced7("toResultStorage:ShowCoalesced",
                                "       'N/A',\n"
                                "       TO_CHAR(ROUND(NVL(a.bytes / b.unit, 0),2)),\n"
                                "       TO_CHAR(ROUND(NVL(f.bytes,0) / b.unit,2)),\n"
+                               "       TO_CHAR(ROUND(NVL(f.bytes,0)/NVL(a.bytes,1)*100)),\n" // free%
                                "       '-',\n"
                                "       '-',\n"
                                "       TO_CHAR(ROUND(f.percent_extents_coalesced,1))||'%',\n"
@@ -282,6 +364,7 @@ static toSQL SQLNoShowCoalesced(
     "       TO_CHAR ( ROUND ( NVL ( f.free_size,\n"
     "                               0 ) / b.unit,\n"
     "                         2 ) ),\n"
+    "       TO_CHAR(ROUND(NVL(f.free_size,0)/NVL(s.tbs_size,1)*100)),\n" // free%
     "       TO_CHAR ( ROUND ( NVL ( s.autoextend_size,\n"
     "                               0 ) / b.unit,\n"
     "                         2 ) ),\n"
@@ -337,6 +420,7 @@ static toSQL SQLNoShowCoalesced8("toResultStorage:NoCoalesced",
                                  "       d.logging,\n"
                                  "       TO_CHAR(ROUND(NVL(a.bytes,0) / b.unit,2)),\n"
                                  "       TO_CHAR(ROUND(NVL(f.bytes,0) / b.unit,2)),\n"
+                                 "       TO_CHAR(ROUND(NVL(f.bytes,0)/NVL(a.bytes,1)*100)),\n" // free%
                                  "       TO_CHAR(ROUND(NVL(a.maxbytes,0) / b.unit,2)),\n"
                                  "       '-',\n"
                                  "       '-',\n"
@@ -360,6 +444,7 @@ static toSQL SQLNoShowCoalesced7("toResultStorage:NoCoalesced",
                                  "       'N/A',\n"
                                  "       TO_CHAR(ROUND(NVL(a.bytes,0) / b.unit,2)),\n"
                                  "       TO_CHAR(ROUND(NVL(f.bytes,0) / b.unit,2)),\n"
+                                 "       TO_CHAR(ROUND(NVL(f.bytes,0)/NVL(a.bytes,1)*100)),\n" // free%
                                  "       '-',\n"
                                  "       '-',\n"
                                  "       '-',\n"
@@ -387,6 +472,7 @@ static toSQL SQLDatafile(
     "                         2 ) ),\n"
     "       to_char ( round ( s.bytes / b.unit,\n"
     "                         2 ) ),\n"
+    "       TO_CHAR(ROUND(NVL(s.bytes,0)/NVL(d.bytes,1)*100)),\n" // free%
     "       to_char ( round ( d.maxbytes / b.unit,\n"
     "                         2 ) ),\n"
     "       '-',\n"
@@ -421,6 +507,7 @@ static toSQL SQLDatafile(
     "                         2 ) ),\n"
     "       to_char ( round ( ( d.user_bytes - t.bytes_cached ) / b.unit,\n"
     "                         2 ) ),\n"
+    "       TO_CHAR(ROUND(NVL(d.user_bytes - t.bytes_cached,0)/NVL(d.bytes,1)*100)),\n" // free%
     "       to_char ( round ( d.maxbytes / b.unit,\n"
     "                         2 ) ),\n"
     "       '-',\n"
@@ -452,6 +539,7 @@ static toSQL SQLDatafile8(
     "                         2 ) ),\n"
     "       to_char ( round ( s.bytes / b.unit,\n"
     "                         2 ) ),\n"
+    "       TO_CHAR(ROUND(NVL(s.bytes,0)/NVL(d.bytes,1)*100)),\n" // free%
     "       to_char ( round ( d.maxbytes / b.unit,\n"
     "                         2 ) ),\n"
     "       '-',\n"
@@ -485,6 +573,7 @@ static toSQL SQLDatafile8(
     "                         2 ) ),\n"
     "       to_char ( round ( ( d.user_bytes - t.bytes_cached ) / b.unit,\n"
     "                         2 ) ),\n"
+    "       TO_CHAR(ROUND(NVL(d.user_bytes - t.bytes_cached,0)/NVL(d.bytes,1)*100)),\n" // free%
     "       to_char ( round ( d.maxbytes / b.unit,\n"
     "                         2 ) ),\n"
     "       '-',\n"
@@ -512,6 +601,7 @@ static toSQL SQLDatafile7("toResultStorage:Datafile",
                           "    ' ',\n"
                           "        to_char(round(d.bytes/b.unit,2)),\n"
                           "        to_char(round(s.bytes/b.unit,2)),\n"
+                          "       TO_CHAR(ROUND(NVL(s.bytes,0)/NVL(d.bytes,1)*100)),\n" // free%
                           "        '-',\n"
                           "        '-',\n"
                           "    ' ',\n"
@@ -528,9 +618,6 @@ static toSQL SQLDatafile7("toResultStorage:Datafile",
                           "",
                           "0703");
 
-#define FILECOLUMNS 14
-#define COLUMNS (FILECOLUMNS-2)
-
 void toResultStorage::saveSelected(void)
 {
     toTreeWidgetItem *item = selectedItem();
@@ -587,18 +674,19 @@ void toResultStorage::updateList(void)
     {
         for (std::list<QString>::iterator j = TablespaceValues.begin();j != TablespaceValues.end();)
         {
-            toTreeWidgetItem *tablespace = new toResultStorageItem(AvailableGraph, this, NULL);
+            toResultStorageItem *tablespace = new toResultStorageItem(AvailableGraph, this, NULL);
             for (int i = 0;i < COLUMNS && j != TablespaceValues.end();i++, j++)
             {
-                if (i == 8)
+                if (i == COL_USED_FREE_AUTO)
                     continue;
                 tablespace->setText(i, *j);
+                tablespace->setSortValue(i, *j);
             }
 
             // To fill Used/Free/Autoextend column
-            double total = tablespace->text(7).toDouble();
-            double user = tablespace->text(5).toDouble();
-            double free = tablespace->text(6).toDouble();
+            double total = tablespace->text(COL_FREE_PERCENT).toDouble();
+            double user = tablespace->text(COL_SIZE).toDouble();
+            double free = tablespace->text(COL_FREE_UNIT).toDouble();
             if (total < user )
                 total = user;
             user /= total;
@@ -607,13 +695,14 @@ void toResultStorage::updateList(void)
 //             t.sprintf("%05.1f / %05.1f / %05.1f%%", (user-free)*100, free*100, (1 - user)*100);
 // spaces seems better than 0-filling...
             t.sprintf("%#5.1f / %#5.1f / %#5.1f%%", (user-free)*100, free*100, (1 - user)*100);
-            tablespace->setText(8,t);
+            tablespace->setText(COL_USED_FREE_AUTO, t);
+            tablespace->setSortValue(COL_USED_FREE_AUTO, (user-free)*100);
             // end of Used/Free/Autoextend column
 
             if (CurrentSpace == tablespace->text(0))
             {
                 if (CurrentFile.isEmpty())
-                    setSelected(tablespace, true);
+                    tablespace->setSelected(true);
             }
         }
     }
@@ -641,9 +730,13 @@ void toResultStorage::updateList(void)
             file = new toResultStorageItem(AvailableGraph, tablespace, NULL);
         }
         for (int i = 0;i < FILECOLUMNS && k != FileValues.end();i++, k++)
+        {
             file->setText(i, *k);
+            reinterpret_cast<toResultStorageItem*>(file)->setSortValue(i, *k);
+        }
 
         file->setText(COLUMNS, name);
+        reinterpret_cast<toResultStorageItem*>(file)->setSortValue(COLUMNS, name);
         if (CurrentSpace == file->text(COLUMNS) &&
                 CurrentFile == file->text(0))
         {
