@@ -2,39 +2,39 @@
 /* BEGIN_COMMON_COPYRIGHT_HEADER
  *
  * TOra - An Oracle Toolkit for DBA's and developers
- * 
+ *
  * Shared/mixed copyright is held throughout files in this product
- * 
+ *
  * Portions Copyright (C) 2000-2001 Underscore AB
  * Portions Copyright (C) 2003-2005 Quest Software, Inc.
  * Portions Copyright (C) 2004-2008 Numerous Other Contributors
- * 
+ *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
  * as published by the Free Software Foundation;  only version 2 of
  * the License is valid for this program.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
- * 
+ *
  *      As a special exception, you have permission to link this program
  *      with the Oracle Client libraries and distribute executables, as long
  *      as you follow the requirements of the GNU GPL in regard to all of the
  *      software in the executable aside from Oracle client libraries.
- * 
+ *
  *      Specifically you are not permitted to link this program with the
  *      Qt/UNIX, Qt/Windows or Qt Non Commercial products of TrollTech.
  *      And you are not permitted to distribute binaries compiled against
- *      these libraries. 
- * 
+ *      these libraries.
+ *
  *      You may link this product with any GPL'd Qt library.
- * 
+ *
  * All trademarks belong to their respective owners.
  *
  * END_COMMON_COPYRIGHT_HEADER */
@@ -79,7 +79,7 @@ class toResultTableViewDelegate : public QItemDelegate
 
 public:
     toResultTableViewDelegate(QObject *parent = 0)
-            : QItemDelegate(parent)
+        : QItemDelegate(parent)
     {
     }
 
@@ -97,8 +97,8 @@ public:
 
 
 class toResultTableView : public QTableView,
-            public toResult,
-            public toEditWidget
+    public toResult,
+    public toEditWidget
 {
     Q_OBJECT;
 
@@ -132,6 +132,9 @@ class toResultTableView : public QTableView,
     // set true when model has signaled
     bool Ready;
 
+    // set true when model has finished.
+    // helps work around determining when query.eof has been reached.
+    bool Finished;
 
     /**
      * context menu items. may be null.
@@ -178,6 +181,9 @@ protected:
     // pointer to model
     QPointer<toResultModel> Model;
 
+    QString Owner;
+    QString Table;
+
     /**
      * overridden from parent.
      *
@@ -253,7 +259,10 @@ public:
     virtual bool searchPrevious(const QString & text);
     virtual void searchReplace(const QString & text) {};
     virtual void searchReplaceAll(const QString & text) {};
-    virtual bool searchCanReplace(bool all) { return false; };
+    virtual bool searchCanReplace(bool all)
+    {
+        return false;
+    };
 
     /**
      * Reimplemented to create query and new model.
@@ -412,8 +421,6 @@ public:
      */
     virtual void editSelectAll(void);
 
-
-
 public slots:
     /**
      * Resizes all columns based on the size hints of the delegate
