@@ -2,39 +2,39 @@
 /* BEGIN_COMMON_COPYRIGHT_HEADER
  *
  * TOra - An Oracle Toolkit for DBA's and developers
- * 
+ *
  * Shared/mixed copyright is held throughout files in this product
- * 
+ *
  * Portions Copyright (C) 2000-2001 Underscore AB
  * Portions Copyright (C) 2003-2005 Quest Software, Inc.
  * Portions Copyright (C) 2004-2009 Numerous Other Contributors
- * 
+ *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
  * as published by the Free Software Foundation;  only version 2 of
  * the License is valid for this program.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
- * 
+ *
  *      As a special exception, you have permission to link this program
  *      with the Oracle Client libraries and distribute executables, as long
  *      as you follow the requirements of the GNU GPL in regard to all of the
  *      software in the executable aside from Oracle client libraries.
- * 
+ *
  *      Specifically you are not permitted to link this program with the
  *      Qt/UNIX, Qt/Windows or Qt Non Commercial products of TrollTech.
  *      And you are not permitted to distribute binaries compiled against
- *      these libraries. 
- * 
+ *      these libraries.
+ *
  *      You may link this product with any GPL'd Qt library.
- * 
+ *
  * All trademarks belong to their respective owners.
  *
  * END_COMMON_COPYRIGHT_HEADER */
@@ -58,10 +58,12 @@ class toSyntaxAnalyzer;
 class toSQLParse
 {
 public:
+    /** Settings for indentation (code formatter)
+     */
     struct settings
     {
         bool ExpandSpaces;
-        bool CommaBefore;
+        bool CommaBefore; // should comma on lists be placed on start of new line
         bool BlockOpenLine;
         bool OperatorSpace;
         bool KeywordUpper;
@@ -98,12 +100,26 @@ public:
             /** Another token of whatever it is detected in.
              */
             Token,
+            /** End of statement marker
+             */
+            EndOfStatement,
             /** Unparsed data
              */
             Raw
             /** Type of token.
              */
         } Type;
+        /** Indicates type of statement - DDL/DML or PLSQL block
+            This is later used when deciding if trailing semicolon should
+            be removed or not before executing.
+         */
+        enum statementClass
+        {
+            unknown,
+            ddldml,     // DML's, create object statements, environment settings etc.
+            plsqlblock  // PLSQL blocks (named and anonymous)
+        } StatementClass;
+
         /** Was there a comment attached to this token
          */
         QString Comment;
@@ -213,17 +229,17 @@ public:
 
     /** Tokenizer class which gets tokens from a string.
      */
-class stringTokenizer : public tokenizer
+    class stringTokenizer : public tokenizer
     {
         QString String;
     public:
         stringTokenizer(const QString &str, int offset = 0, int line = 0)
-                : tokenizer(offset, line)
+            : tokenizer(offset, line)
         {
             String = str;
         }
         stringTokenizer(const QString &str, toSyntaxAnalyzer &analyzer, int offset = 0, int line = 0)
-                : tokenizer(analyzer, offset, line)
+            : tokenizer(analyzer, offset, line)
         {
             String = str;
         }
@@ -240,7 +256,7 @@ class stringTokenizer : public tokenizer
 
     /** Tokenizer class which gets tokens from an editor.
      */
-class editorTokenizer : public tokenizer
+    class editorTokenizer : public tokenizer
     {
         toMarkedText *Editor;
     public:
