@@ -337,6 +337,9 @@ bool toIsMySQL(const toConnection &);
 /** Check if this connection is an PostgreSQL connection.
  */
 bool toIsPostgreSQL(const toConnection &);
+/** Check if this connection is a Teradata connection.
+ */
+bool toIsTeradata(const toConnection &);
 /** Strip extra bind specifier from an SQL statement. (That means the extra <***> part after
  * the bind variable.
  * @param sql The sql to strip.
@@ -395,13 +398,18 @@ void toMapImport(std::map<QString, QString> &data, const QString &prefix,
  */
 toTreeWidgetItem *toFindItem(toTreeWidget *list, const QString &str);
 /** Whenever this class is instantiated the window will display a busy cursor. You
- * can instantiate this function as many time as you want, only when all of them are
+ * can instantiate this function as many times as you want, only when all of them are
  * destructed the curser will revert back to normal.
+ * If you want to control if busy cursor is actually shown for a particular case, you
+ * can use a boolean parameter in constructor. For example debugger is setting this as
+ * false in order for cursor NOT to be busy until program unit being debugged finishes.
  */
 class toBusy
 {
+private:
+    bool Busy;
 public:
-    toBusy();
+    toBusy(bool busy = true);
     ~toBusy();
 };
 /**
